@@ -1,6 +1,7 @@
 package etcd
 
 import (
+	"context"
 	"testing"
 
 	authorizationapi "k8s.io/api/authorization/v1"
@@ -44,7 +45,7 @@ type testSAR struct {
 	sar   *authorizationapi.SubjectAccessReview
 }
 
-func (t *testSAR) Create(subjectAccessReview *authorizationapi.SubjectAccessReview) (*authorizationapi.SubjectAccessReview, error) {
+func (t *testSAR) Create(_ context.Context, subjectAccessReview *authorizationapi.SubjectAccessReview, _ metav1.CreateOptions) (*authorizationapi.SubjectAccessReview, error) {
 	t.sar = subjectAccessReview
 	return &authorizationapi.SubjectAccessReview{
 		Status: authorizationapi.SubjectAccessReviewStatus{
@@ -94,7 +95,7 @@ func TestCreate(t *testing.T) {
 }
 
 func TestCreateWithAllocation(t *testing.T) {
-	allocator := &testAllocator{Hostname: "bar"}
+	allocator := &testAllocator{Hostname: "bar.com"}
 	storage, server := newStorage(t, allocator)
 	defer server.Terminate(t)
 	defer storage.Store.DestroyFunc()
@@ -104,7 +105,7 @@ func TestCreateWithAllocation(t *testing.T) {
 		t.Fatalf("unable to create object: %v", err)
 	}
 	result := obj.(*routeapi.Route)
-	if result.Spec.Host != "bar" {
+	if result.Spec.Host != "bar.com" {
 		t.Fatalf("unexpected route: %#v", result)
 	}
 	if v, ok := result.Annotations[route.HostGeneratedAnnotationKey]; !ok || v != "true" {
